@@ -53,6 +53,12 @@ AWS_HEADERS = {
 
 AWS_QUERYSTRING_AUTH = False
 
+AWS_S3_SECURE_URLS = False
+
+AWS_REDUCED_REDUNDANCY = False
+
+AWS_IS_GZIPPED = True
+
 
 # Email settings.
 
@@ -112,7 +118,6 @@ INSTALLED_APPS = (
     "django.contrib.messages",
     "django.contrib.staticfiles",
     "django.contrib.admin",
-    "django.contrib.sitemaps",
     "herokuapp",
     "require",
     "usertools",
